@@ -1,3 +1,5 @@
+#ifndef INCLUDE_RUBY_CONFIG_H
+#define INCLUDE_RUBY_CONFIG_H 1
 /* confdefs.h */
 #define CANONICALIZATION_FOR_MATHN 1
 #define STDC_HEADERS 1
@@ -27,26 +29,35 @@
 #define SIZEOF_FLOAT 4
 #define SIZEOF_DOUBLE 8
 #define SIZEOF_TIME_T 4
+#define PRI_LL_PREFIX "ll"
 #define rb_pid_t pid_t
 #define PIDT2NUM(v) INT2NUM(v)
 #define NUM2PIDT(v) NUM2INT(v)
-#define PRI_PIDT_PREFIX ""
+#define PRI_PIDT_PREFIX PRI_INT_PREFIX
 #define rb_uid_t uid_t
 #define UIDT2NUM(v) UINT2NUM(v)
 #define NUM2UIDT(v) NUM2UINT(v)
-#define PRI_UIDT_PREFIX ""
+#define PRI_UIDT_PREFIX PRI_INT_PREFIX
 #define rb_gid_t gid_t
 #define GIDT2NUM(v) UINT2NUM(v)
 #define NUM2GIDT(v) NUM2UINT(v)
-#define PRI_GIDT_PREFIX ""
+#define PRI_GIDT_PREFIX PRI_INT_PREFIX
 #define rb_time_t time_t
 #define TIMET2NUM(v) INT2NUM(v)
 #define NUM2TIMET(v) NUM2INT(v)
-#define PRI_TIMET_PREFIX ""
+#define PRI_TIMET_PREFIX PRI_INT_PREFIX
 #define rb_dev_t dev_t
 #define DEVT2NUM(v) INT2NUM(v)
 #define NUM2DEVT(v) NUM2INT(v)
-#define PRI_DEVT_PREFIX ""
+#define PRI_DEVT_PREFIX PRI_INT_PREFIX
+#define rb_mode_t mode_t
+#define MODET2NUM(v) UINT2NUM(v)
+#define NUM2MODET(v) NUM2UINT(v)
+#define PRI_MODET_PREFIX PRI_INT_PREFIX
+#define rb_rlim_t rlim_t
+#define RLIM2NUM(v) ULL2NUM(v)
+#define NUM2RLIM(v) NUM2ULL(v)
+#define PRI_RLIM_PREFIX PRI_LL_PREFIX
 #define HAVE_PROTOTYPES 1
 #define TOKEN_PASTE(x,y) x##y
 #define STRINGIZE(expr) STRINGIZE0(expr)
@@ -57,6 +68,8 @@
 #define NOINLINE(x) __attribute__ ((noinline)) x
 #define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
 #define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
+#define HAVE_GCC_ATOMIC_BUILTINS 1
+#define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
 #define HAVE_DECL_SYS_NERR 1
 #define HAVE_DIRENT_H 1
 #define HAVE__BOOL 1
@@ -84,9 +97,10 @@
 #define HAVE_LOCALE_H 1
 #define HAVE_TIME_H 1
 #define HAVE_SYS_SOCKET_H 1
-#define SIZEOF_RLIM_T 8
 #define SIZEOF_SIZE_T 8
 #define SIZEOF_PTRDIFF_T 8
+#define PRI_SIZE_PREFIX "z"
+#define PRI_PTRDIFF_PREFIX "t"
 #define HAVE_STRUCT_STAT_ST_BLKSIZE 1
 #define HAVE_ST_BLKSIZE 1
 #define HAVE_STRUCT_STAT_ST_BLOCKS 1
@@ -106,6 +120,7 @@
 #define HAVE_STRUCT_STAT_ST_CTIMENSEC 1
 #define HAVE_STRUCT_TIMESPEC 1
 #define HAVE_STRUCT_TIMEZONE 1
+#define HAVE_CLOCKID_T 1
 #define HAVE_RB_FD_INIT 1
 #define HAVE_INT8_T 1
 #define SIZEOF_INT8_T 1
@@ -129,6 +144,7 @@
 #define SIZEOF_UINTPTR_T 8
 #define HAVE_SSIZE_T 1
 #define SIZEOF_SSIZE_T 8
+#define GC_MARK_STACKFRAME_WORD 18
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_ALLOCA 1
@@ -150,6 +166,8 @@
 #define HAVE_CBRT 1
 #define HAVE_STRLCPY 1
 #define HAVE_STRLCAT 1
+#define HAVE_FFS 1
+#define HAVE_SETPROCTITLE 1
 #define HAVE_SIGNBIT 1
 #define HAVE_FMOD 1
 #define HAVE_KILLPG 1
@@ -200,6 +218,7 @@
 #define HAVE_SETRLIMIT 1
 #define HAVE_SYSCONF 1
 #define HAVE_CLOSE 1
+#define HAVE_GETGRNAM_R 1
 #define HAVE_DLOPEN 1
 #define HAVE_SIGPROCMASK 1
 #define HAVE_SIGACTION 1
@@ -225,9 +244,11 @@
 #define HAVE_GMTIME_R 1
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_GETTIMEOFDAY 1
+#define HAVE_POLL 1
 #define HAVE_PREAD 1
 #define HAVE_SHUTDOWN 1
 #define HAVE_SIGALTSTACK 1
+#define HAVE_DL_ITERATE_PHDR 1
 #define RUBY_SETJMP(env) _setjmp(env)
 #define RUBY_LONGJMP(env,val) _longjmp(env,val)
 #define RUBY_JMP_BUF jmp_buf
@@ -237,7 +258,6 @@
 #define HAVE_TIMEZONE 1
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
-#define GETPGRP_VOID 1
 #define RSHIFT(x,y) ((x)>>(int)(y))
 #define FILE_COUNT _r
 #define FILE_READPTR _p
@@ -247,11 +267,12 @@
 #define _REENTRANT 1
 #define _THREAD_SAFE 1
 #define HAVE_LIBPTHREAD 1
-#define HAVE_NANOSLEEP 1
+#define HAVE_PTHREAD_NP_H 1
 #define HAVE_SCHED_YIELD 1
 #define HAVE_PTHREAD_ATTR_SETINHERITSCHED 1
 #define HAVE_PTHREAD_ATTR_GETSTACK 1
 #define HAVE_PTHREAD_STACKSEG_NP 1
+#define HAVE_PTHREAD_SIGMASK 1
 #define USE_ELF 1
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
@@ -262,3 +283,4 @@
 #define RUBY_SITE_LIB RUBY_LIB_PREFIX"/site_ruby"
 #define RUBY_VENDOR_LIB RUBY_LIB_PREFIX"/vendor_ruby"
 #define RUBY_PLATFORM "x86_64-openbsd"
+#endif /* INCLUDE_RUBY_CONFIG_H */
