@@ -3,8 +3,8 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION == "1.9.2" or
-    raise "ruby lib version (1.9.2) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "1.9.3" or
+    raise "ruby lib version (1.9.3) doesn't match executable version (#{RUBY_VERSION})"
 
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.9.1/alpha-openbsd")
   DESTDIR = '' unless defined? DESTDIR
@@ -13,15 +13,18 @@ module RbConfig
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "9"
   CONFIG["TEENY"] = "1"
-  CONFIG["PATCHLEVEL"] = "290"
+  CONFIG["PATCHLEVEL"] = "0"
   CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby19"
   CONFIG["RUBY_INSTALL_NAME"] = "ruby19"
   CONFIG["RUBY_SO_NAME"] = "ruby19"
+  CONFIG["exec"] = "exec"
+  CONFIG["ruby_pc"] = "ruby-1.9.pc"
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " newline.c"
+  CONFIG["USE_RUBYGEMS"] = "YES"
   CONFIG["MANTYPE"] = "man"
   CONFIG["NROFF"] = "/bin/false"
   CONFIG["vendorhdrdir"] = "$(rubyhdrdir)/vendor_ruby"
@@ -40,6 +43,7 @@ module RbConfig
   CONFIG["rubylibprefix"] = "$(libdir)/$(RUBY_BASE_NAME)"
   CONFIG["MAKEFILES"] = "Makefile"
   CONFIG["THREAD_MODEL"] = "pthread"
+  CONFIG["SYMBOL_PREFIX"] = ""
   CONFIG["EXPORT_PREFIX"] = ""
   CONFIG["COMMON_HEADERS"] = ""
   CONFIG["COMMON_MACROS"] = ""
@@ -53,22 +57,25 @@ module RbConfig
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.0.0"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.0"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
   CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -shared $(CCDLFLAGS)"
-  CONFIG["warnflags"] = "-Wall -Wno-unused-parameter -Wno-parentheses -Wpointer-arith -Wwrite-strings -Wno-long-long"
+  CONFIG["warnflags"] = "-Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Werror=pointer-arith -Werror=write-strings -Werror=declaration-after-statement -Werror=implicit-function-declaration"
   CONFIG["debugflags"] = "-g"
   CONFIG["optflags"] = "-O3"
   CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
   CONFIG["cflags"] = " $(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include"
+  CONFIG["NULLCMD"] = ":"
   CONFIG["INSTALLDOC"] = "all"
+  CONFIG["CAPITARGET"] = "nodoc"
   CONFIG["RDOCTARGET"] = "rdoc"
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
+  CONFIG["LIBRUBY_RELATIVE"] = "no"
   CONFIG["EXTOUT"] = ".ext"
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
   CONFIG["TEST_RUNNABLE"] = "yes"
@@ -90,12 +97,14 @@ module RbConfig
   CONFIG["ARCH_FLAG"] = ""
   CONFIG["DLDFLAGS"] = ""
   CONFIG["ALLOCA"] = ""
+  CONFIG["WERRORFLAG"] = "-Werror"
   CONFIG["CHDIR"] = "cd -P"
   CONFIG["RMALL"] = "rm -fr"
-  CONFIG["RMDIRS"] = "$(top_srcdir)/tool/rmdirs"
+  CONFIG["RMDIRS"] = "rmdir -p"
+  CONFIG["RMDIR"] = "rmdir"
   CONFIG["CP"] = "cp"
   CONFIG["RM"] = "rm -f"
-  CONFIG["CAPITARGET"] = "nodoc"
+  CONFIG["PKG_CONFIG"] = ""
   CONFIG["DOXYGEN"] = ""
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
@@ -105,9 +114,9 @@ module RbConfig
   CONFIG["INSTALL_PROGRAM"] = "install -c -s -o root -g bin -m 555"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
+  CONFIG["NM"] = "nm"
   CONFIG["DLLWRAP"] = ""
   CONFIG["WINDRES"] = ""
-  CONFIG["NM"] = ""
   CONFIG["OBJCOPY"] = "objcopy"
   CONFIG["OBJDUMP"] = "objdump"
   CONFIG["ASFLAGS"] = ""
@@ -120,8 +129,8 @@ module RbConfig
   CONFIG["CPPOUTFILE"] = "-o conftest.i"
   CONFIG["GNU_LD"] = "yes"
   CONFIG["GCC"] = "yes"
-  CONFIG["EGREP"] = "/usr/local/bin/ggrep -E"
-  CONFIG["GREP"] = "/usr/local/bin/ggrep"
+  CONFIG["EGREP"] = "/usr/bin/egrep"
+  CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "$(CC) -E"
   CONFIG["CXXFLAGS"] = "-O2 -pipe"
   CONFIG["CXX"] = "c++"
@@ -130,22 +139,22 @@ module RbConfig
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -Wl,-E"
   CONFIG["CFLAGS"] = "-mieee -O2 -pipe -fPIC"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd5.0"
+  CONFIG["target_os"] = "openbsd5.1"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "alpha"
-  CONFIG["target"] = "alpha-unknown-openbsd5.0"
-  CONFIG["host_os"] = "openbsd5.0"
+  CONFIG["target"] = "alpha-unknown-openbsd5.1"
+  CONFIG["host_os"] = "openbsd5.1"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "alpha"
-  CONFIG["host"] = "alpha-unknown-openbsd5.0"
-  CONFIG["build_os"] = "openbsd5.0"
-  CONFIG["build_vendor"] = "unknown"
-  CONFIG["build_cpu"] = "alpha"
-  CONFIG["build"] = "alpha-unknown-openbsd5.0"
+  CONFIG["host"] = "alpha-unknown-openbsd5.1"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["RUBY_RELEASE_DATE"] = "2011-07-09"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "1.9.2"
+  CONFIG["build_os"] = "openbsd5.1"
+  CONFIG["build_vendor"] = "unknown"
+  CONFIG["build_cpu"] = "alpha"
+  CONFIG["build"] = "alpha-unknown-openbsd5.1"
+  CONFIG["RUBY_RELEASE_DATE"] = "2011-10-30"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "1.9.3"
   CONFIG["BASERUBY"] = "echo executable host ruby is required.  use --with-baseruby option.; false"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
@@ -223,5 +232,5 @@ module RbConfig
     )
   end
 end
-Config = RbConfig # compatibility for ruby-1.8.4 and older.
+autoload :Config, "rbconfig/obsolete.rb" # compatibility for ruby-1.8.4 and older.
 CROSS_COMPILING = nil unless defined? CROSS_COMPILING
